==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Button/CompoundButton/CompoundButton.js <==
import '../../node_modules/core-js/modules/es.date.to-string.js';
import '../../node_modules/core-js/modules/es.object.to-string.js';
import '../../node_modules/core-js/modules/es.reflect.construct.js';
import '../../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent.js';
import '../../node_modules/core-js/modules/es.symbol.js';
import '../../node_modules/core-js/modules/es.array.filter.js';
import '../../node_modules/core-js/modules/es.array.for-each.js';
import '../../node_modules/core-js/modules/es.object.define-properties.js';
import '../../node_modules/core-js/modules/es.object.define-property.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../../node_modules/core-js/modules/es.object.keys.js';
import '../../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { BaseButton } from '../BaseButton.js';
import { getStyles } from './CompoundButton.styles.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var CompoundButton = function (_BaseComponent) {
  _inherits(CompoundButton, _BaseComponent);

  var _super = _createSuper(CompoundButton);

  function CompoundButton() {
    _classCallCheck(this, CompoundButton);

    return _super.apply(this, arguments);
  }

  _createClass(CompoundButton, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var primary = this.primary,
          internalStyles = this.internalStyles;
      var props = {
        variantClassName: primary ? 'ms-Button--compoundPrimary' : 'ms-Button--compound',
        styles: internalStyles
      };
      return h(BaseButton, {
        "props": _objectSpread({}, props),
        "attrs": _objectSpread({}, this.$attrs)
      }, [this.$slots["default"]]);
    }
  }, {
    key: "internalStyles",
    get: function get() {
      var _this$primary = this.primary,
          primary = _this$primary === void 0 ? false : _this$primary,
          theme = this.theme;
      var styles = {};
      return getStyles(theme, styles, primary);
    }
  }]);

  return CompoundButton;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], CompoundButton.prototype, "primary", void 0);

CompoundButton = __decorate([Component], CompoundButton);

export { CompoundButton };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Button/CompoundButton/CompoundButton.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent.js';
import 'core-js/modules/es.symbol';
import 'core-js/modules/es.array.filter';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.object.get-own-property-descriptor';
import 'core-js/modules/es.object.get-own-property-descriptors';
import 'core-js/modules/es.object.keys';
import 'core-js/modules/web.dom-collections.for-each';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { BaseButton } from '../BaseButton.js';
import { getStyles } from './CompoundButton.styles.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var CompoundButton = function (_BaseComponent) {
  _inherits(CompoundButton, _BaseComponent);

  var _super = _createSuper(CompoundButton);

  function CompoundButton() {
    _classCallCheck(this, CompoundButton);

    return _super.apply(this, arguments);
  }

  _createClass(CompoundButton, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var primary = this.primary,
          internalStyles = this.internalStyles;
      var props = {
        variantClassName: primary ? 'ms-Button--compoundPrimary' : 'ms-Button--compound',
        styles: internalStyles
      };
      return h(BaseButton, {
        "props": _objectSpread({}, props),
        "attrs": _objectSpread({}, this.$attrs)
      }, [this.$slots.default]);
    }
  }, {
    key: "internalStyles",
    get: function get() {
      var _this$primary = this.primary,
          primary = _this$primary === void 0 ? false : _this$primary,
          theme = this.theme;
      var styles = {};
      return getStyles(theme, styles, primary);
    }
  }]);

  return CompoundButton;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], CompoundButton.prototype, "primary", void 0);

CompoundButton = __decorate([Component], CompoundButton);

export { CompoundButton };
